/*
    Boost Software License - Version 1.0 - August 17th, 2003

    Permission is hereby granted, free of charge, to any person or organization
    obtaining a copy of the software and accompanying documentation covered by
    this license (the "Software") to use, reproduce, display, distribute,
    execute, and transmit the Software, and to prepare derivative works of the
    Software, and to permit third-parties to whom the Software is furnished to
    do so, all subject to the following:

    The copyright notices in the Software and this entire statement, including
    the above license grant, this restriction and the following disclaimer,
    must be included in all copies of the Software, in whole or in part, and
    all derivative works of the Software, unless such copies or derivative
    works are solely in the form of machine-executable object code generated by
    a source language processor.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
    SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
    FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
    ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
    DEALINGS IN THE SOFTWARE.

*/

#ifndef _AGENDA_AGENDA_HPP
#define _AGENDA_AGENDA_HPP

#include <vector>
#include "Person.hpp"
#include "Property.hpp"
#include <boost/signals2.hpp>
#include <iostream>


namespace NAgenda {
  
class Agenda
{
public:
  typedef Agenda ClassName;
private:    
  std::vector<Person> persons_;
  int posicion_;
  
  Person * getPersonaActual();
  
  void setPosicion(std::size_t pos) {
      posicion_ = pos;
  }
  
  std::size_t getPosicion() const { return posicion_; }
  
public:
  GUINYOTE_ROPROPERTY_NOSETTER(PersonaActual);
  GUINYOTE_ROPROPERTY(Posicion);
  
  
  typedef decltype(persons_.begin()) iterator;
  typedef decltype(persons_.cbegin()) const_iterator;
  typedef Person value_type;
  typedef std::random_access_iterator_tag iterator_category;
  
  
  Agenda();
  
  Agenda(const Agenda &) = delete;
  Agenda & operator=(const Agenda &) = delete;
  
  auto begin() -> decltype(persons_.begin()) { return persons_.begin(); }
  auto end() -> decltype(persons_.begin()) { return persons_.end(); }
  
  void Anyadir(Person && p);
  void Modificar(Person && p);
  
  void siguienteEntrada();
  void anteriorEntrada();
};

}

#endif // AGENDA_HPP
