/*
    Boost Software License - Version 1.0 - August 17th, 2003

    Permission is hereby granted, free of charge, to any person or organization
    obtaining a copy of the software and accompanying documentation covered by
    this license (the "Software") to use, reproduce, display, distribute,
    execute, and transmit the Software, and to prepare derivative works of the
    Software, and to permit third-parties to whom the Software is furnished to
    do so, all subject to the following:

    The copyright notices in the Software and this entire statement, including
    the above license grant, this restriction and the following disclaimer,
    must be included in all copies of the Software, in whole or in part, and
    all derivative works of the Software, unless such copies or derivative
    works are solely in the form of machine-executable object code generated by
    a source language processor.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
    SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
    FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
    ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
    DEALINGS IN THE SOFTWARE.

*/

#ifndef _AGENDA_PERSON_HPP
#define _AGENDA_PERSON_HPP

#include "Property.hpp"
#include <string>

namespace NAgenda {
  
class Person
{  
public:
 
    Guinyote::TROProperty<std::string> Name;
    Guinyote::TROProperty<std::string> SurName;
    
    Person(const std::string & name, const std::string & surname);
    
    Person(const Person &) = delete;
    Person & operator=(const Person &) = delete;
    
    Person(Person && other);
    Person & operator=(Person && other);
    
    
    bool operator<(const Person & other) const
    {
      if (SurName < other.SurName)
	return true;
      return Name < other.Name;
    }
    
    bool operator==(const Person & other) const 
    {
      return (SurName == other.SurName && Name == other.Name);
    }
    
    void swap(Person & other);
    
    friend std::ostream & operator<<(std::ostream & out, const Person & p);
};



}


#endif // PERSON_HPP
